@@ -121,9 +121,10 @@ event_line <- function(data,
     stop("Please ensure you have spelled the desired metric correctly.")
   }
 
-  index_start <- index_end <- NULL
+  index_start <- index_end <- event_idx <-  NULL
 
-  event <- event[order(-abs(event[colnames(event) == metric])),]
+  event_idx <- as.vector(-abs(event[colnames(event) == metric])[,1])
+  event <- event[base::order(event_idx),]
   event <- event %>%
     dplyr::filter(duration >= min_duration) %>%
     dplyr::mutate(index_start_fix = index_start - 1,
@@ -280,7 +281,7 @@ event_line <- function(data,
       theme(legend.direction = "vertical")
     ep
 
-  } else{
+  } else {
 
     lineCol <- c(
       "Temperature" = "black",
@@ -371,7 +372,7 @@ lolli_plot <- function(data,
   event <- data$event %>%
     dplyr::select(metric, xaxis)
 
-  y_top <- as.numeric(event[which(abs(event[ ,1]) == max(abs(event[ ,1])))[1], 1])*1.05
+  y_top <- as.numeric(event[which(abs(event[ ,1]) == max(abs(event[ ,1])))[1], 1]) * 1.05
   if (y_top >= 0) y_limits <- c(0, y_top)
   if (y_top < 0) y_limits <- c(y_top, 0)
 
